guix_mirror_bot pushed a commit to branch core-packages-team
in repository guix.

commit 7d56e3b89c27ab05e10b57f147b7515ac3991e90
Author: Nicolas Graves <[email protected]>
AuthorDate: Wed Feb 18 00:10:52 2026 +0100

    gnu: hello-mesboot: Improve style.
    
    * gnu/packages/commencement.scm (hello-mesboot)[arguments]: Improve
    style, use G-expressions.
    
    Change-Id: Ia2770fb4cdd7b718e04a1d1643f65ea7af7708b9
    Signed-off-by: Ludovic Courtès <[email protected]>
---
 gnu/packages/commencement.scm | 23 ++++++++++++-----------
 1 file changed, 12 insertions(+), 11 deletions(-)

diff --git a/gnu/packages/commencement.scm b/gnu/packages/commencement.scm
index 928e814c02..2a058633e8 100644
--- a/gnu/packages/commencement.scm
+++ b/gnu/packages/commencement.scm
@@ -1510,17 +1510,18 @@ ac_cv_c_float_format='IEEE (little-endian)'
     (propagated-inputs '())
     (native-inputs (%boot-mesboot2-inputs))
     (arguments
-     `(#:implicit-inputs? #f
-       #:guile ,%bootstrap-guile
-       #:parallel-build? #f
-       ;; checking for grep that handles long lines and -e...
-       ;; configure: error: no acceptable grep could be found
-       #:configure-flags '("ac_cv_path_GREP=grep")
-       #:phases
-       (modify-phases %standard-phases
-         (replace 'check
-           (lambda _
-             (invoke "./hello"))))))))
+     (list
+      #:implicit-inputs? #f
+      #:guile %bootstrap-guile
+      #:parallel-build? #f
+      ;; checking for grep that handles long lines and -e...
+      ;; configure: error: no acceptable grep could be found
+      #:configure-flags #~(list "ac_cv_path_GREP=grep")
+      #:phases
+      #~(modify-phases %standard-phases
+          (replace 'check
+            (lambda _
+              (invoke "./hello"))))))))
 
 (define binutils-mesboot
   (package

Reply via email to